@@ -30,7 +30,9 @@ def calc_ion_mz(
         no_mod: bool = False,
         c_with_fixed_mod: bool = False,
         pep_preprocess_func: typing.Union[str, bool, typing.Callable] = None,
+        mass_offset: float = None,
         return_single_value_if_one_input: bool = True,
+        fill_na_if_unsupported: bool = False,
 ) -> typing.Union[float, np.ndarray]:
     """
     :param pep:
@@ -43,6 +45,7 @@ def calc_ion_mz(
     :param ion_charge:
         Ion charge state (precursor or fragment)
         Should have same number of components as `ion_type`
+        Use `0` to calculate mass instead of m/z
     :param ion_series_num:
         If `ion_type` is not None, this param should be provided to calc mz for certain fragments.
         Can be None, int, or list of None/int. Mz of multi ions will be returned if list is provided.
@@ -62,7 +65,10 @@ def calc_ion_mz(
             will use '{' as the starting char and '}' as the ending one
     :param mods:
         Explicitly provided modifications. When this param is not None, modifications will not be parsed from input peptide text.
-        Can be str like `1,Carbamidomethyl;3,Oxidation;`, or list like `[(1, 'Carbamidomethyl'), (3, 'Oxidation')]`
+        Can be str like
+            `1,Carbamidomethyl;3,Oxidation;`,
+            or list like `[(1, 'Carbamidomethyl'), (3, 'Oxidation')]`,
+            or list with float as mod mass `[(1, 57.0214637), (3, 79.9663304084)]`
     :param no_mod:
         If set to True, input `pep` will be regarded as stripped peptide, and no modification on it (param `c_with_fixed_mod` will still have effect)
     :param c_with_fixed_mod:
@@ -72,9 +78,12 @@ def calc_ion_mz(
         A function to preprocess input peptide before any other action
         For example: use `lambda x: x.replace('_', '').replace('.', '')` to remove all `.` and `_` at first
         The above example can also be used by setting this param to 'underscore_dot' or set to True
+    :param mass_offset:
+
     :param return_single_value_if_one_input:
         If True, will return a single value but not ndarray when input is single
         If False, multi inputs will lead to multi outputs as an n-d numpy array, and single input will lead to a 1-d array
+    :param fill_na_if_unsupported:
 
     :return: float or ndarray
         ion m/z
@@ -130,7 +139,7 @@ def calc_ion_mz(
     )
     -> 529.2252677999999
 
-    calc_ion_mz(
+    mskit.calc.calc_ion_mz(
         '_[Acetyl (Protein N-term)]SGSS[Phospho (STY)]SVAAMKK_',
         [3, 4, 1, 1, 1, 2, 1, 1],
         ion_type=[None, None, 'y', 'y', 'b', 'y', 'b', 'y'],
@@ -141,6 +150,26 @@ def calc_ion_mz(
     -> array([392.17730633, 294.3847989 , 901.42128059, 450.34558439,
        529.2252678 , 523.24102465, 930.434943  , 406.24825189])
 
+   # The previous one equals to the following two ways to set modifications
+    mskit.calc.calc_ion_mz(
+        'SGSSSVAAMKK',
+        [3, 4, 1, 1, 1, 2, 1, 1],
+        ion_type=[None, None, 'y', 'y', 'b', 'y', 'b', 'y'],
+        ion_series_num=[None, None, 8, 5, 6, 10, 10, 3],
+        ion_loss_type=[None, None, 'Noloss', '1,H3PO4', '1,H3PO4', 'noloss', '1,H3PO4', None],
+        mods=[(0, 'Acetyl (Protein N-term)'), (4, 'Phospho (STY)')],
+        pep_preprocess_func='underscore_dot'
+    )
+    mskit.calc.calc_ion_mz(
+        'SGSSSVAAMKK',
+        [3, 4, 1, 1, 1, 2, 1, 1],
+        ion_type=[None, None, 'y', 'y', 'b', 'y', 'b', 'y'],
+        ion_series_num=[None, None, 8, 5, 6, 10, 10, 3],
+        ion_loss_type=[None, None, 'Noloss', '1,H3PO4', '1,H3PO4', 'noloss', '1,H3PO4', None],
+        mods=[(0, 42.0105646863), (4, 79.9663304084)],
+        pep_preprocess_func='underscore_dot'
+    )
+
     """
 
     if pep_preprocess_func is not None:
@@ -179,9 +208,9 @@ def calc_ion_mz(
     pep_len = len(stripped_pep)
 
     if ion_type is None or isinstance(ion_type, str):
-        if not isinstance(ion_charge, int):
+        if not isinstance(ion_charge, (int, np.integer)):
             raise ValueError(f'Expect an integer as `ion_charge`. Now is {ion_charge} with type as {type(ion_charge)}')
-        if ion_series_num is not None and not isinstance(ion_series_num, int):
+        if ion_series_num is not None and not isinstance(ion_series_num, (int, np.integer)):
             raise ValueError(f'Expect None or an integer as `ion_series_num`. Now is {ion_series_num} with type as {type(ion_series_num)}')
         ion_type = ('b',) if ion_type is None else (ion_type,)
         ion_charge = (ion_charge,)
@@ -222,21 +251,24 @@ def calc_ion_mz(
         for _p, _n in zip(mod_poss, mod_names):
             _pos_to_mod_name[_p].append(_n)
 
-        _mass = sum([Mass.ModMass[m] for m in _mods]) if (_mods := _pos_to_mod_name.get(0)) is not None else 0.
+        _mass = sum([(m if isinstance(m, float) else Mass.ModMass[m]) for m in _mods]) if (_mods := _pos_to_mod_name.get(0)) is not None else 0.
+        _mass = _mass + mass_offset if mass_offset is not None else _mass
         for pos in range(1, max(needed_ions_subset.keys()) + 1):
             _mass += Mass.ResMass[stripped_pep[pos - 1]]
             if c_with_fixed_mod and stripped_pep[pos - 1] == 'C':
                 _mass += Mass.ModMass['Carbamidomethyl']
             if (_mods := _pos_to_mod_name.get(pos)) is not None:
-                _mass += sum([Mass.ModMass[m] for m in _mods])
+                _mass += sum([(m if isinstance(m, float) else Mass.ModMass[m]) for m in _mods])
             if pos == pep_len:
                 _mass += CompoundMass.CompoundMass['H2O']  # diff with y
 
             for i_c, i_l, idx in needed_ions_subset[pos]:
                 this_mass = _mass + Mass.ProtonMass * i_c
-                if i_l is None or i_l.lower() == 'noloss':
+                if i_l is None:
                     pass
-                elif isinstance(i_l, (float, int)):
+                elif isinstance(i_l, str) and (i_l.lower() == 'noloss' or i_l == ''):
+                    pass
+                elif isinstance(i_l, (float, int, np.inexact, np.integer)):
                     this_mass -= i_l
                 else:
                     for loss in i_l.strip(';').split(';'):
@@ -254,20 +286,23 @@ def calc_ion_mz(
             else:
                 _pos_to_mod_name[pep_len + 1 - _p].append(_n)  # diff with b
 
-        _mass = sum([Mass.ModMass[m] for m in _mods]) if (_mods := _pos_to_mod_name.get(0)) is not None else 0.
+        _mass = sum([(m if isinstance(m, float) else Mass.ModMass[m]) for m in _mods]) if (_mods := _pos_to_mod_name.get(0)) is not None else 0.
         _mass += CompoundMass.CompoundMass['H2O']  # diff with b
+        _mass = _mass + mass_offset if mass_offset is not None else _mass
         for pos in range(1, max(needed_ions_subset.keys()) + 1):
             _mass += Mass.ResMass[stripped_pep[pos - 1]]
             if c_with_fixed_mod and stripped_pep[pos - 1] == 'C':
                 _mass += Mass.ModMass['Carbamidomethyl']
             if (_mods := _pos_to_mod_name.get(pos)) is not None:
-                _mass += sum([Mass.ModMass[m] for m in _mods])
+                _mass += sum([(m if isinstance(m, float) else Mass.ModMass[m]) for m in _mods])
 
             for i_c, i_l, idx in needed_ions_subset[pos]:
                 this_mass = _mass + Mass.ProtonMass * i_c
-                if i_l is None or i_l.lower() == 'noloss':
+                if i_l is None:
                     pass
-                elif isinstance(i_l, (float, int)):
+                elif isinstance(i_l, str) and (i_l.lower() == 'noloss' or i_l == ''):
+                    pass
+                elif isinstance(i_l, (float, int, np.inexact, np.integer)):
                     this_mass -= i_l
                 else:
                     for loss in i_l.strip(';').split(';'):
@@ -281,16 +316,34 @@ def calc_ion_mz(
         return result
 
 
+def ion_mz_from_mass(mass: float, charge: int):
+    pass
+
+
 class MassCalc(object):
     ResMass = copy.deepcopy(Mass.ResMass)
     ModMass = copy.deepcopy(Mass.ModMass)
 
     def __init__(self):
+        """
+
+        """
+
         self._cache = dict()
 
         # if c_with_fix_mod:
         #     self.ResMass['C'] = self.ResMass['C+']
 
+    def valid_mass(self):
+        """
+        candidate_mods
+        mass_tol
+        mz_tol
+
+        :return:
+        """
+        pass
+
 
 def calc_prec_mz(pep: str, charge: int = None, mod=None) -> float:
     """
