@@ -8,6 +8,26 @@ def element_aa2res(aa_comp: dict) -> dict:
 class AAComp:
     AAElement = {
         'A': {'C': 3, 'N': 1, 'O': 2, 'H': 7},
+        'R': {'C': 6, 'N': 4, 'O': 2, 'H': 14},
+        'N': {'C': 4, 'N': 2, 'O': 3, 'H': 8},
+        'D': {'C': 4, 'N': 1, 'O': 4, 'H': 7},
+        'C': {'C': 3, 'N': 1, 'O': 2, 'H': 7, 'S': 1},
+        'C+': {'C': 5, 'N': 2, 'O': 3, 'H': 10, 'S': 1},
+        'Q': {'C': 5, 'N': 2, 'O': 3, 'H': 10},
+        'E': {'C': 5, 'N': 1, 'O': 4, 'H': 9},
+        'G': {'C': 2, 'N': 1, 'O': 2, 'H': 5},
+        'H': {'C': 6, 'N': 3, 'O': 2, 'H': 9},
+        'I': {'C': 6, 'N': 1, 'O': 2, 'H': 13, },
+        'L': {'C': 6, 'N': 1, 'O': 2, 'H': 13, },
+        'K': {'C': 6, 'N': 2, 'O': 2, 'H': 14, },
+        'M': {'C': 5, 'N': 1, 'O': 2, 'H': 11, 'S': 1},
+        'F': {'C': 9, 'N': 1, 'O': 2, 'H': 11, },
+        'P': {'C': 5, 'N': 1, 'O': 2, 'H': 9},
+        'S': {'C': 3, 'N': 1, 'O': 3, 'H': 7},
+        'T': {'C': 4, 'N': 1, 'O': 3, 'H': 9},
+        'W': {'C': 11, 'N': 2, 'O': 2, 'H': 12},
+        'Y': {'C': 9, 'N': 1, 'O': 3, 'H': 11},
+        'V': {'C': 5, 'N': 1, 'O': 2, 'H': 11},
     }
 
 
