@@ -1,5 +1,5 @@
-from . import robust
+from . import robustness
 from . import similarity
 from .distance import frechet_dist
-from .robust import iqr, cv, fwhm, count_missing_values
+from .robustness import iqr, cv, fwhm, count_missing_values
 from .similarity import pcc, sa
