@@ -1,8 +1,10 @@
 
 from ._spectronaut import SpectronautLibrary
 
-from ._spectronaut import sn_constant
-from ._spectronaut import sn_utils
-from ._spectronaut.sn_utils import *
+from ._spectronaut import lib_utils
 from ._spectronaut import mod_process
+from ._spectronaut import sn_constant
+from ._spectronaut import sn_phossite
 from ._spectronaut import sn_result
+from ._spectronaut import utils
+from ._spectronaut.utils import *
