@@ -1,4 +1,4 @@
-from . import deep_phospho
+from . import deepphospho
 from . import deepms2
 from . import deeprt
 from . import pdeep
