@@ -1,6 +1,8 @@
 from .data_struc_kit import *
-from .dir_kit import *
+from .db_kit import *
 from .file_kit import *
+from .log_kit import *
+from .module_kit import *
 from .pd_kit import *
 from .sys_kit import *
 from .text_kit import *
